/**************************************************************************
*  Copyright (c) 2013-2015 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  21.12.2013  mifi  First Version
**************************************************************************/
#if defined(USE_BOARD_EIR)
#define __ETH_CONFIG_C__

/*=======================================================================*/
/*  Include                                                              */
/*=======================================================================*/
#include "tal.h"

/*=======================================================================*/
/*  All Structures and Common Constants                                  */
/*=======================================================================*/

/*
 * SMC2 Chip Select Register definition
 */
#define SMC_CSR2_NWS_BIT      0
#define SMC_CSR2_WSEN_BIT     7
#define SMC_CSR2_TDF_BIT      8
#define SMC_CSR2_BAT_BIT      12          
#define SMC_CSR2_DBW_BIT      13
#define SMC_CSR2_RWSETUP_BIT  24
#define SMC_CSR2_RWHOLD_BIT   28

/*=======================================================================*/
/*  Definition of all local Data                                         */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Procedures                                   */
/*=======================================================================*/

/*=======================================================================*/
/*  All code exported                                                    */
/*=======================================================================*/

/*************************************************************************/
/*  BoardETHConfig                                                       */
/*                                                                       */
/*  Configure the GPIO ports for ethernet pins.                          */
/*                                                                       */
/*  In    : none                                                         */
/*  Out   : none                                                         */
/*  Return: none                                                         */
/*************************************************************************/
void BoardETHConfig (void)
{
   /* 
    * Enable Ethernet controller chip select. 
    */
   AT91C_BASE_PIOA->PIO_BSR = AT91C_PIO_PA20;
   AT91C_BASE_PIOA->PIO_PDR = AT91C_PIO_PA20;
   
   /*
    * Enable external memory read, write and wait signals. 
    */
   AT91C_BASE_PIOC->PIO_BSR = (AT91C_PIO_PC16 | AT91C_PIO_PC21 | AT91C_PIO_PC22);
   AT91C_BASE_PIOC->PIO_PDR = (AT91C_PIO_PC16 | AT91C_PIO_PC21 | AT91C_PIO_PC22);
   
   /* 
    * Configure Ethernet controller chip select. 
    */
   AT91C_BASE_SMC->SMC2_CSR[2] = ( (1 << SMC_CSR2_NWS_BIT)     |
                                   (1 << SMC_CSR2_WSEN_BIT)    |
                                   (2 << SMC_CSR2_TDF_BIT)     |
                                   (1 << SMC_CSR2_BAT_BIT)     |
                                   (1 << SMC_CSR2_DBW_BIT)     |
                                   (1 << SMC_CSR2_RWSETUP_BIT) |
                                   (1 << SMC_CSR2_RWHOLD_BIT)  );
                                   
   /*
    * Enable peripheral clock of PIOC.
    */
   AT91C_BASE_PMC->PMC_PCER = (1 << AT91C_ID_PIOC);
    
   /*
    * Configure PWR_RST# pin of the DM9000
    */  
   AT91C_BASE_PIOC->PIO_SODR = AT91C_PIO_PC17;
   AT91C_BASE_PIOC->PIO_PER  = AT91C_PIO_PC17;
   AT91C_BASE_PIOC->PIO_OER  = AT91C_PIO_PC17;
} /* BoardETHConfig */

#endif /* USE_BOARD_EIR */

/*** EOF ***/
